@@ -1,11 +1,14 @@
 package Mock::Data::Charset;
 use strict;
 use warnings;
-use Carp ();
+use Mock::Data::Util qw( _parse_context _escape_str );
+require Carp;
 our @CARP_NOT= ('Mock::Data::Util');
+require Mock::Data::Generator;
+our @ISA= ( 'Mock::Data::Generator' );
 
 # ABSTRACT: Generator of strings from a set of characters
-our $VERSION = '0.00_001'; # TRIAL VERSION
+our $VERSION = '0.01'; # VERSION
 
 
 our @generator_attrs= qw( str_len min_codepoint max_codepoint );
@@ -306,7 +309,6 @@ sub generate {
 	if ($self->{members} || $member_count < 500) {
 		my $members= $self->members;
 		return sub {
-			return $self->generate(@_) if @_ > 1;
 			my $buf= '';
 			$buf .= $members->[$memb_min + int rand $memb_span]
 				for 1..$len->($_[0]);
@@ -321,7 +323,6 @@ sub generate {
 		my $invlist= $self->member_invlist;
 		my $index= $self->_invlist_index;
 		return sub {
-			return $self->generate(@_) if @_ > 1;
 			my $ret= '';
 			$ret .= chr _get_invlist_element($memb_min + int rand($memb_span), $invlist, $index)
 				for 1..$len->($_[0]);
@@ -360,16 +361,6 @@ sub parse {
 	return _parse_charset() for $notation;
 }
 
-my %_escape_common= ( "\n" => '\n', "\t" => '\t', "\0" => '\0' );
-sub _escape_str {
-	my $str= shift;
-	$str =~ s/([^\x20-\x7E])/ $_escape_common{$1} || sprintf("\\x{%02X}",ord $1) /ge;
-	return $str;
-}
-sub _parse_context {
-	return '"' . _escape_str(substr($_, pos, 10)) .'"';
-}
-
 our $have_prop_invlist;
 our @_backslash_h_invlist= (
   0x09,0x0A, 0x20,0x21, 0xA0,0xA1, 0x1680,0x1681, 0x2000,0x200B, 0x202F,0x2030,
@@ -459,6 +450,7 @@ sub _parse_charset_classname {
 	undef
 }
 sub _parse_charset {
+	my $flags= shift;
 	# argument is in $_, starting from pos($_)
 	my %parse;
 	my @range;
@@ -493,6 +485,9 @@ sub _parse_charset {
 				last; # $1 eq ']';
 			}
 		}
+		elsif ($flags && ($flags->{x}||0) >= 2 && /\G[ \t]/gc) {
+			next; # ignore space and tab under /xx
+		}
 		else {
 			/\G(.)/gc or die "Unexpected end of input";
 			$cp= ord $1;
@@ -945,7 +940,7 @@ Michael Conrad <mike@nrdvana.net>
 
 =head1 VERSION
 
-version 0.00_001
+version 0.01
 
 =head1 COPYRIGHT AND LICENSE
 
